@@ -26,7 +26,7 @@ class AttributeSelector(Plugin):
         if self.attribs or self.eval_attribs:
             self.register()
 
-    def startTestRun(self, event):
+    def moduleLoadedSuite(self, event):
         """Filter event.suite by specified attributes"""
         log.debug('Attribute selector attribs %s/%s',
                   self.attribs, self.eval_attribs)
