@@ -3,6 +3,15 @@ import unittest
 from nose2.tools import such
 
 
+class SomeLayer(object):
+    @classmethod
+    def setUp(cls):
+        it.somelayer = True
+
+    @classmethod
+    def tearDown(cls):
+        del it.somelayer
+
 #
 # Such tests start with a declaration about the system under test
 # and will typically bind the test declaration to a variable with
@@ -84,6 +93,16 @@ with such.A('system with complex setup') as it:
         # A layer may have any number of sub-layers.
         #
         with it.having('a different precondition'):
+
+            #
+            # A layer defined with ``having`` can make use of
+            # layers defined elsewhere. An external layer
+            # pulled in with ``it.uses`` becomes a parent
+            # of the current layer (though it doesn't actually
+            # get injected into the layer's MRO).
+            #
+            it.uses(SomeLayer)
+
             @it.has_setup
             def setup():
                 it.things.append(99)
@@ -118,6 +137,15 @@ with such.A('system with complex setup') as it:
                 assert it.is_funny
                 assert case.is_funny
 
+            @it.should('have access to an external fixture')
+            def test(case):
+                assert it.somelayer
+
+            with it.having('a case inside the external fixture'):
+                @it.should('still have access to that fixture')
+                def test(case):
+                    assert it.somelayer
+
 #
 # To convert the layer definitions into test cases, you have to call
 # `createTests` and pass in the module globals, so that the test cases
