@@ -215,8 +215,7 @@ class Scenario(object):
     def _makeGroupTest(self, mod, group, parent_layer=None, position=0):
         layer = self._makeLayer(group, parent_layer, position)
         case = self._makeTestCase(group, layer)
-        log.debug("Made test case %s with layer %s from %s position %s",
-                  case, layer, group, position)
+        log.debug("Made test case %s with layer %s from %s", case, layer, group)
         mod[layer.__name__] = layer
         layer.__module__ = mod['__name__']
         mod[case.__name__] = case
@@ -305,8 +304,8 @@ class Scenario(object):
             layer = type("%s:layer" % group.description, (parent_layer,), attr)
         if group.mixins:
             layer.mixins = getattr(layer, 'mixins', ()) + tuple(group.mixins)
-        log.debug("made layer %s with bases %s and mixins %s at %s",
-                  layer, layer.__bases__, layer.mixins, position)
+        log.debug("made layer %s with bases %s and mixins %s",
+                  layer, layer.__bases__, layer.mixins)
         return layer
 
 
